@@ -25,6 +25,18 @@ class FileNotExistError(RezBuildException):
     pass
 
 
+class InstallerNotFoundError(RezBuildException):
+    """When can't find installer."""
+
+    pass
+
+
+class NotFoundPythonInBinError(RezBuildException):
+    """When can't find python executable path in entry point file."""
+
+    pass
+
+
 class ReNotMatchError(RezBuildException):
     """When the regex does not match."""
 
